@@ -1,6 +1,6 @@
-import os
 from typing import Union
 
+from gensim.models.keyedvectors import KeyedVectors
 from spacy.language import Language
 
 from .conceptualizer import ConceptualSpacy
@@ -10,18 +10,21 @@ from .conceptualizer import ConceptualSpacy
     "concise_concepts",
     default_config={
         "data": None,
-        "topn": []
+        "topn": [],
+        "model_path": None
     },
 )
 def make_concise_concepts(
     nlp: Language,
     name: str,
     data: Union[dict, list],
-    topn: list
+    topn: list,
+    model_path: Union[str, None]
 ):  
     return ConceptualSpacy(
         nlp=nlp,
         name=name,
         data=data,
-        topn=topn
+        topn=topn,
+        model_path=model_path
     )
